@@ -4,7 +4,7 @@ use feature 'signatures';
 
 package YAMLScript::Reader;
 
-use Lingy::Common;
+use YAMLScript::Common;
 use Lingy::Reader;
 
 use base 'Lingy::Reader';
@@ -220,7 +220,7 @@ sub construct_ast($s, $n) {
             L(
                 S('apply'),
                 S('main'),
-                S('*ARGV*'),
+                S('*command-line-args*'),
             ),
 
         );
@@ -647,7 +647,7 @@ sub group_print($s, $g) {
     '(' .
     join(' ',
         map {
-            ref ? $s->group_print($_) : $_;
+            ref($_) ? $s->group_print($_) : $_;
         } @$g
     )
     . ')';
@@ -724,7 +724,7 @@ sub compose_ali {
 #------------------------------------------------------------------------------
 {
     no warnings 'redefine';
-    sub Lingy::Common::_dump {
+    sub YAMLScript::Common::_dump {
         (my $type = (caller(1))[3]) =~ s/.*://;
         my $sub = (caller(2))[3];
         my $line = (caller(1))[2];
@@ -742,7 +742,6 @@ sub tag_error($msg) { ZZZ "$msg: '$_'" }
 sub o {
     my $f = (caller(1))[3];
     my $t = $_[0] // '';
-#     warn "\n--> $f $t\n";
     return 0;
 }
 
